@@ -4,7 +4,7 @@ __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2020 Altertech'
 __license__ = 'Apache License 2.0'
 
-__version__ = '0.0.7'
+__version__ = '0.0.9'
 
 import sys
 import argparse
@@ -175,7 +175,7 @@ def main():
                     help='Loop (production)',
                     action='store_true')
     ap.add_argument('-R',
-                    '--restart',
+                    '--auto-restart',
                     help='Auto restart loop on errors',
                     action='store_true')
     a = ap.parse_args()
